summaryrefslogtreecommitdiffstats
path: root/src/kicondialog.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:55:33 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:55:33 -0600
commitae6cafee5339716bd01aa6c66aa4f366bdc5d43b (patch)
treedb682cc1b772442e3ac4986b8f66119531291a4e /src/kicondialog.cpp
parent882bcd26b3d60be72ea2b35921969a9850c52db9 (diff)
downloadbasket-ae6cafee5339716bd01aa6c66aa4f366bdc5d43b.tar.gz
basket-ae6cafee5339716bd01aa6c66aa4f366bdc5d43b.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 882bcd26b3d60be72ea2b35921969a9850c52db9.
Diffstat (limited to 'src/kicondialog.cpp')
-rw-r--r--src/kicondialog.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/kicondialog.cpp b/src/kicondialog.cpp
index 295fdb4..85e923e 100644
--- a/src/kicondialog.cpp
+++ b/src/kicondialog.cpp
@@ -86,7 +86,7 @@ KIconDialog::KIconDialog(TQWidget *parent, const char*)
d = new KIconDialogPrivate;
mpLoader = KGlobal::iconLoader();
init();
- resize(minimumSize());
+ resize(tqminimumSize());
}
KIconDialog::KIconDialog(KIconLoader *loader, TQWidget *parent,
@@ -256,7 +256,7 @@ void KIconDialog::setup(KIcon::Group group, KIcon::Context context,
d->extendedContext = static_cast<ExtendedContext>( ( context == KIcon::Any ) ? ALL : context + 1 );
- // We cannot change layout because it is protected ;-(
+ // We cannot change tqlayout because it is protected ;-(
// FIXME: TQt4 we will be able to inherit from both TQDialog and our GUI
d->ui->listBox->setEnabled(!lockContext);
d->ui->browseButton->setEnabled(!lockBrowse);
@@ -277,7 +277,7 @@ void KIconDialog::setCustomLocation( const TQString& location )
if (location.isEmpty())
{
- mFileList = KGlobal::dirs()->findAllResources("appicon", TQString::fromLatin1("*.png"));
+ mFileList = KGlobal::dirs()->findAllResources("appicon", TQString::tqfromLatin1("*.png"));
} else {
mFileList = mpLoader->queryIconsByDir(location);
}
@@ -304,7 +304,7 @@ void KIconDialog::showDialog()
{
d->custom = TQString();
// Make it so minimumSize returns correct value
d->ui->filterLabel->hide();
d->ui->searchLine->hide();
d->ui->progressBar->show();
@@ -313,7 +313,7 @@ void KIconDialog::showDialog()
show();
// FIXME: this should be before show() but it doesn't work ;-(
- resize(minimumSize());
+ resize(tqminimumSize());
showIcons();
}
@@ -304,7 +304,7 @@ void KIconDialog::showDialog()
{
d->custom = TQString();
- // Make it so minimumSize returns correct value
+ // Make it so tqminimumSize returns correct value
d->ui->filterLabel->hide();
d->ui->searchLine->hide();